@@ -85,24 +85,24 @@ class Exceptions:
 
 class MachineLearningClient:
     """
-    [MachineLearning.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Client)
+    [MachineLearning.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Client)
     """
 
     exceptions: Exceptions
 
     def add_tags(
         self,
-        Tags: List[TagTypeDef],
+        Tags: List["TagTypeDef"],
         ResourceId: str,
         ResourceType: Literal["BatchPrediction", "DataSource", "Evaluation", "MLModel"],
     ) -> AddTagsOutputTypeDef:
         """
-        [Client.add_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Client.add_tags)
+        [Client.add_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Client.add_tags)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Client.can_paginate)
         """
 
     def create_batch_prediction(
@@ -114,7 +114,7 @@ class MachineLearningClient:
         BatchPredictionName: str = None,
     ) -> CreateBatchPredictionOutputTypeDef:
         """
-        [Client.create_batch_prediction documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Client.create_batch_prediction)
+        [Client.create_batch_prediction documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Client.create_batch_prediction)
         """
 
     def create_data_source_from_rds(
@@ -126,7 +126,7 @@ class MachineLearningClient:
         ComputeStatistics: bool = None,
     ) -> CreateDataSourceFromRDSOutputTypeDef:
         """
-        [Client.create_data_source_from_rds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Client.create_data_source_from_rds)
+        [Client.create_data_source_from_rds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Client.create_data_source_from_rds)
         """
 
     def create_data_source_from_redshift(
@@ -138,7 +138,7 @@ class MachineLearningClient:
         ComputeStatistics: bool = None,
     ) -> CreateDataSourceFromRedshiftOutputTypeDef:
         """
-        [Client.create_data_source_from_redshift documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Client.create_data_source_from_redshift)
+        [Client.create_data_source_from_redshift documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Client.create_data_source_from_redshift)
         """
 
     def create_data_source_from_s3(
@@ -149,7 +149,7 @@ class MachineLearningClient:
         ComputeStatistics: bool = None,
     ) -> CreateDataSourceFromS3OutputTypeDef:
         """
-        [Client.create_data_source_from_s3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Client.create_data_source_from_s3)
+        [Client.create_data_source_from_s3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Client.create_data_source_from_s3)
         """
 
     def create_evaluation(
@@ -160,7 +160,7 @@ class MachineLearningClient:
         EvaluationName: str = None,
     ) -> CreateEvaluationOutputTypeDef:
         """
-        [Client.create_evaluation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Client.create_evaluation)
+        [Client.create_evaluation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Client.create_evaluation)
         """
 
     def create_ml_model(
@@ -174,37 +174,37 @@ class MachineLearningClient:
         RecipeUri: str = None,
     ) -> CreateMLModelOutputTypeDef:
         """
-        [Client.create_ml_model documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Client.create_ml_model)
+        [Client.create_ml_model documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Client.create_ml_model)
         """
 
     def create_realtime_endpoint(self, MLModelId: str) -> CreateRealtimeEndpointOutputTypeDef:
         """
-        [Client.create_realtime_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Client.create_realtime_endpoint)
+        [Client.create_realtime_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Client.create_realtime_endpoint)
         """
 
     def delete_batch_prediction(self, BatchPredictionId: str) -> DeleteBatchPredictionOutputTypeDef:
         """
-        [Client.delete_batch_prediction documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Client.delete_batch_prediction)
+        [Client.delete_batch_prediction documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Client.delete_batch_prediction)
         """
 
     def delete_data_source(self, DataSourceId: str) -> DeleteDataSourceOutputTypeDef:
         """
-        [Client.delete_data_source documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Client.delete_data_source)
+        [Client.delete_data_source documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Client.delete_data_source)
         """
 
     def delete_evaluation(self, EvaluationId: str) -> DeleteEvaluationOutputTypeDef:
         """
-        [Client.delete_evaluation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Client.delete_evaluation)
+        [Client.delete_evaluation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Client.delete_evaluation)
         """
 
     def delete_ml_model(self, MLModelId: str) -> DeleteMLModelOutputTypeDef:
         """
-        [Client.delete_ml_model documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Client.delete_ml_model)
+        [Client.delete_ml_model documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Client.delete_ml_model)
         """
 
     def delete_realtime_endpoint(self, MLModelId: str) -> DeleteRealtimeEndpointOutputTypeDef:
         """
-        [Client.delete_realtime_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Client.delete_realtime_endpoint)
+        [Client.delete_realtime_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Client.delete_realtime_endpoint)
         """
 
     def delete_tags(
@@ -214,7 +214,7 @@ class MachineLearningClient:
         ResourceType: Literal["BatchPrediction", "DataSource", "Evaluation", "MLModel"],
     ) -> DeleteTagsOutputTypeDef:
         """
-        [Client.delete_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Client.delete_tags)
+        [Client.delete_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Client.delete_tags)
         """
 
     def describe_batch_predictions(
@@ -241,7 +241,7 @@ class MachineLearningClient:
         Limit: int = None,
     ) -> DescribeBatchPredictionsOutputTypeDef:
         """
-        [Client.describe_batch_predictions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Client.describe_batch_predictions)
+        [Client.describe_batch_predictions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Client.describe_batch_predictions)
         """
 
     def describe_data_sources(
@@ -261,7 +261,7 @@ class MachineLearningClient:
         Limit: int = None,
     ) -> DescribeDataSourcesOutputTypeDef:
         """
-        [Client.describe_data_sources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Client.describe_data_sources)
+        [Client.describe_data_sources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Client.describe_data_sources)
         """
 
     def describe_evaluations(
@@ -288,7 +288,7 @@ class MachineLearningClient:
         Limit: int = None,
     ) -> DescribeEvaluationsOutputTypeDef:
         """
-        [Client.describe_evaluations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Client.describe_evaluations)
+        [Client.describe_evaluations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Client.describe_evaluations)
         """
 
     def describe_ml_models(
@@ -317,7 +317,7 @@ class MachineLearningClient:
         Limit: int = None,
     ) -> DescribeMLModelsOutputTypeDef:
         """
-        [Client.describe_ml_models documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Client.describe_ml_models)
+        [Client.describe_ml_models documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Client.describe_ml_models)
         """
 
     def describe_tags(
@@ -326,7 +326,7 @@ class MachineLearningClient:
         ResourceType: Literal["BatchPrediction", "DataSource", "Evaluation", "MLModel"],
     ) -> DescribeTagsOutputTypeDef:
         """
-        [Client.describe_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Client.describe_tags)
+        [Client.describe_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Client.describe_tags)
         """
 
     def generate_presigned_url(
@@ -337,64 +337,64 @@ class MachineLearningClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Client.generate_presigned_url)
         """
 
     def get_batch_prediction(self, BatchPredictionId: str) -> GetBatchPredictionOutputTypeDef:
         """
-        [Client.get_batch_prediction documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Client.get_batch_prediction)
+        [Client.get_batch_prediction documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Client.get_batch_prediction)
         """
 
     def get_data_source(
         self, DataSourceId: str, Verbose: bool = None
     ) -> GetDataSourceOutputTypeDef:
         """
-        [Client.get_data_source documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Client.get_data_source)
+        [Client.get_data_source documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Client.get_data_source)
         """
 
     def get_evaluation(self, EvaluationId: str) -> GetEvaluationOutputTypeDef:
         """
-        [Client.get_evaluation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Client.get_evaluation)
+        [Client.get_evaluation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Client.get_evaluation)
         """
 
     def get_ml_model(self, MLModelId: str, Verbose: bool = None) -> GetMLModelOutputTypeDef:
         """
-        [Client.get_ml_model documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Client.get_ml_model)
+        [Client.get_ml_model documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Client.get_ml_model)
         """
 
     def predict(
         self, MLModelId: str, Record: Dict[str, str], PredictEndpoint: str
     ) -> PredictOutputTypeDef:
         """
-        [Client.predict documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Client.predict)
+        [Client.predict documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Client.predict)
         """
 
     def update_batch_prediction(
         self, BatchPredictionId: str, BatchPredictionName: str
     ) -> UpdateBatchPredictionOutputTypeDef:
         """
-        [Client.update_batch_prediction documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Client.update_batch_prediction)
+        [Client.update_batch_prediction documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Client.update_batch_prediction)
         """
 
     def update_data_source(
         self, DataSourceId: str, DataSourceName: str
     ) -> UpdateDataSourceOutputTypeDef:
         """
-        [Client.update_data_source documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Client.update_data_source)
+        [Client.update_data_source documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Client.update_data_source)
         """
 
     def update_evaluation(
         self, EvaluationId: str, EvaluationName: str
     ) -> UpdateEvaluationOutputTypeDef:
         """
-        [Client.update_evaluation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Client.update_evaluation)
+        [Client.update_evaluation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Client.update_evaluation)
         """
 
     def update_ml_model(
         self, MLModelId: str, MLModelName: str = None, ScoreThreshold: float = None
     ) -> UpdateMLModelOutputTypeDef:
         """
-        [Client.update_ml_model documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Client.update_ml_model)
+        [Client.update_ml_model documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Client.update_ml_model)
         """
 
     @overload
@@ -402,7 +402,7 @@ class MachineLearningClient:
         self, operation_name: Literal["describe_batch_predictions"]
     ) -> DescribeBatchPredictionsPaginator:
         """
-        [Paginator.DescribeBatchPredictions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeBatchPredictions)
+        [Paginator.DescribeBatchPredictions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeBatchPredictions)
         """
 
     @overload
@@ -410,7 +410,7 @@ class MachineLearningClient:
         self, operation_name: Literal["describe_data_sources"]
     ) -> DescribeDataSourcesPaginator:
         """
-        [Paginator.DescribeDataSources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeDataSources)
+        [Paginator.DescribeDataSources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeDataSources)
         """
 
     @overload
@@ -418,7 +418,7 @@ class MachineLearningClient:
         self, operation_name: Literal["describe_evaluations"]
     ) -> DescribeEvaluationsPaginator:
         """
-        [Paginator.DescribeEvaluations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeEvaluations)
+        [Paginator.DescribeEvaluations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeEvaluations)
         """
 
     @overload
@@ -426,7 +426,7 @@ class MachineLearningClient:
         self, operation_name: Literal["describe_ml_models"]
     ) -> DescribeMLModelsPaginator:
         """
-        [Paginator.DescribeMLModels documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeMLModels)
+        [Paginator.DescribeMLModels documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeMLModels)
         """
 
     @overload
@@ -434,7 +434,7 @@ class MachineLearningClient:
         self, waiter_name: Literal["batch_prediction_available"]
     ) -> BatchPredictionAvailableWaiter:
         """
-        [Waiter.BatchPredictionAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Waiter.BatchPredictionAvailable)
+        [Waiter.BatchPredictionAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Waiter.BatchPredictionAvailable)
         """
 
     @overload
@@ -442,17 +442,17 @@ class MachineLearningClient:
         self, waiter_name: Literal["data_source_available"]
     ) -> DataSourceAvailableWaiter:
         """
-        [Waiter.DataSourceAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Waiter.DataSourceAvailable)
+        [Waiter.DataSourceAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Waiter.DataSourceAvailable)
         """
 
     @overload
     def get_waiter(self, waiter_name: Literal["evaluation_available"]) -> EvaluationAvailableWaiter:
         """
-        [Waiter.EvaluationAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Waiter.EvaluationAvailable)
+        [Waiter.EvaluationAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Waiter.EvaluationAvailable)
         """
 
     @overload
     def get_waiter(self, waiter_name: Literal["ml_model_available"]) -> MLModelAvailableWaiter:
         """
-        [Waiter.MLModelAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.21/reference/services/machinelearning.html#MachineLearning.Waiter.MLModelAvailable)
+        [Waiter.MLModelAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/machinelearning.html#MachineLearning.Waiter.MLModelAvailable)
         """
