@@ -3,9 +3,9 @@ Main interface for machinelearning service type definitions.
 
 Usage::
 
-    from mypy_boto3.machinelearning.type_defs import AddTagsOutputTypeDef
+    from mypy_boto3.machinelearning.type_defs import BatchPredictionTypeDef
 
-    data: AddTagsOutputTypeDef = {...}
+    data: BatchPredictionTypeDef = {...}
 """
 from datetime import datetime
 import sys
@@ -22,6 +22,20 @@ else:
 
 
 __all__ = (
+    "BatchPredictionTypeDef",
+    "DataSourceTypeDef",
+    "EvaluationTypeDef",
+    "MLModelTypeDef",
+    "PerformanceMetricsTypeDef",
+    "PredictionTypeDef",
+    "RDSDatabaseCredentialsTypeDef",
+    "RDSDatabaseTypeDef",
+    "RDSMetadataTypeDef",
+    "RealtimeEndpointInfoTypeDef",
+    "RedshiftDatabaseCredentialsTypeDef",
+    "RedshiftDatabaseTypeDef",
+    "RedshiftMetadataTypeDef",
+    "TagTypeDef",
     "AddTagsOutputTypeDef",
     "CreateBatchPredictionOutputTypeDef",
     "CreateDataSourceFromRDSOutputTypeDef",
@@ -29,7 +43,6 @@ __all__ = (
     "CreateDataSourceFromS3OutputTypeDef",
     "CreateEvaluationOutputTypeDef",
     "CreateMLModelOutputTypeDef",
-    "RealtimeEndpointInfoTypeDef",
     "CreateRealtimeEndpointOutputTypeDef",
     "DeleteBatchPredictionOutputTypeDef",
     "DeleteDataSourceOutputTypeDef",
@@ -37,31 +50,18 @@ __all__ = (
     "DeleteMLModelOutputTypeDef",
     "DeleteRealtimeEndpointOutputTypeDef",
     "DeleteTagsOutputTypeDef",
-    "BatchPredictionTypeDef",
     "DescribeBatchPredictionsOutputTypeDef",
-    "RDSDatabaseTypeDef",
-    "RDSMetadataTypeDef",
-    "RedshiftDatabaseTypeDef",
-    "RedshiftMetadataTypeDef",
-    "DataSourceTypeDef",
     "DescribeDataSourcesOutputTypeDef",
-    "PerformanceMetricsTypeDef",
-    "EvaluationTypeDef",
     "DescribeEvaluationsOutputTypeDef",
-    "MLModelTypeDef",
     "DescribeMLModelsOutputTypeDef",
-    "TagTypeDef",
     "DescribeTagsOutputTypeDef",
     "GetBatchPredictionOutputTypeDef",
     "GetDataSourceOutputTypeDef",
     "GetEvaluationOutputTypeDef",
     "GetMLModelOutputTypeDef",
     "PaginatorConfigTypeDef",
-    "PredictionTypeDef",
     "PredictOutputTypeDef",
-    "RDSDatabaseCredentialsTypeDef",
     "RDSDataSpecTypeDef",
-    "RedshiftDatabaseCredentialsTypeDef",
     "RedshiftDataSpecTypeDef",
     "S3DataSpecTypeDef",
     "UpdateBatchPredictionOutputTypeDef",
@@ -71,6 +71,164 @@ __all__ = (
     "WaiterConfigTypeDef",
 )
 
+BatchPredictionTypeDef = TypedDict(
+    "BatchPredictionTypeDef",
+    {
+        "BatchPredictionId": str,
+        "MLModelId": str,
+        "BatchPredictionDataSourceId": str,
+        "InputDataLocationS3": str,
+        "CreatedByIamUser": str,
+        "CreatedAt": datetime,
+        "LastUpdatedAt": datetime,
+        "Name": str,
+        "Status": Literal["PENDING", "INPROGRESS", "FAILED", "COMPLETED", "DELETED"],
+        "OutputUri": str,
+        "Message": str,
+        "ComputeTime": int,
+        "FinishedAt": datetime,
+        "StartedAt": datetime,
+        "TotalRecordCount": int,
+        "InvalidRecordCount": int,
+    },
+    total=False,
+)
+
+DataSourceTypeDef = TypedDict(
+    "DataSourceTypeDef",
+    {
+        "DataSourceId": str,
+        "DataLocationS3": str,
+        "DataRearrangement": str,
+        "CreatedByIamUser": str,
+        "CreatedAt": datetime,
+        "LastUpdatedAt": datetime,
+        "DataSizeInBytes": int,
+        "NumberOfFiles": int,
+        "Name": str,
+        "Status": Literal["PENDING", "INPROGRESS", "FAILED", "COMPLETED", "DELETED"],
+        "Message": str,
+        "RedshiftMetadata": "RedshiftMetadataTypeDef",
+        "RDSMetadata": "RDSMetadataTypeDef",
+        "RoleARN": str,
+        "ComputeStatistics": bool,
+        "ComputeTime": int,
+        "FinishedAt": datetime,
+        "StartedAt": datetime,
+    },
+    total=False,
+)
+
+EvaluationTypeDef = TypedDict(
+    "EvaluationTypeDef",
+    {
+        "EvaluationId": str,
+        "MLModelId": str,
+        "EvaluationDataSourceId": str,
+        "InputDataLocationS3": str,
+        "CreatedByIamUser": str,
+        "CreatedAt": datetime,
+        "LastUpdatedAt": datetime,
+        "Name": str,
+        "Status": Literal["PENDING", "INPROGRESS", "FAILED", "COMPLETED", "DELETED"],
+        "PerformanceMetrics": "PerformanceMetricsTypeDef",
+        "Message": str,
+        "ComputeTime": int,
+        "FinishedAt": datetime,
+        "StartedAt": datetime,
+    },
+    total=False,
+)
+
+MLModelTypeDef = TypedDict(
+    "MLModelTypeDef",
+    {
+        "MLModelId": str,
+        "TrainingDataSourceId": str,
+        "CreatedByIamUser": str,
+        "CreatedAt": datetime,
+        "LastUpdatedAt": datetime,
+        "Name": str,
+        "Status": Literal["PENDING", "INPROGRESS", "FAILED", "COMPLETED", "DELETED"],
+        "SizeInBytes": int,
+        "EndpointInfo": "RealtimeEndpointInfoTypeDef",
+        "TrainingParameters": Dict[str, str],
+        "InputDataLocationS3": str,
+        "Algorithm": Literal["sgd"],
+        "MLModelType": Literal["REGRESSION", "BINARY", "MULTICLASS"],
+        "ScoreThreshold": float,
+        "ScoreThresholdLastUpdatedAt": datetime,
+        "Message": str,
+        "ComputeTime": int,
+        "FinishedAt": datetime,
+        "StartedAt": datetime,
+    },
+    total=False,
+)
+
+PerformanceMetricsTypeDef = TypedDict(
+    "PerformanceMetricsTypeDef", {"Properties": Dict[str, str]}, total=False
+)
+
+PredictionTypeDef = TypedDict(
+    "PredictionTypeDef",
+    {
+        "predictedLabel": str,
+        "predictedValue": float,
+        "predictedScores": Dict[str, float],
+        "details": Dict[Literal["PredictiveModelType", "Algorithm"], str],
+    },
+    total=False,
+)
+
+RDSDatabaseCredentialsTypeDef = TypedDict(
+    "RDSDatabaseCredentialsTypeDef", {"Username": str, "Password": str}
+)
+
+RDSDatabaseTypeDef = TypedDict(
+    "RDSDatabaseTypeDef", {"InstanceIdentifier": str, "DatabaseName": str}
+)
+
+RDSMetadataTypeDef = TypedDict(
+    "RDSMetadataTypeDef",
+    {
+        "Database": "RDSDatabaseTypeDef",
+        "DatabaseUserName": str,
+        "SelectSqlQuery": str,
+        "ResourceRole": str,
+        "ServiceRole": str,
+        "DataPipelineId": str,
+    },
+    total=False,
+)
+
+RealtimeEndpointInfoTypeDef = TypedDict(
+    "RealtimeEndpointInfoTypeDef",
+    {
+        "PeakRequestsPerSecond": int,
+        "CreatedAt": datetime,
+        "EndpointUrl": str,
+        "EndpointStatus": Literal["NONE", "READY", "UPDATING", "FAILED"],
+    },
+    total=False,
+)
+
+RedshiftDatabaseCredentialsTypeDef = TypedDict(
+    "RedshiftDatabaseCredentialsTypeDef", {"Username": str, "Password": str}
+)
+
+RedshiftDatabaseTypeDef = TypedDict(
+    "RedshiftDatabaseTypeDef", {"DatabaseName": str, "ClusterIdentifier": str}
+)
+
+RedshiftMetadataTypeDef = TypedDict(
+    "RedshiftMetadataTypeDef",
+    {"RedshiftDatabase": "RedshiftDatabaseTypeDef", "DatabaseUserName": str, "SelectSqlQuery": str},
+    total=False,
+)
+
+TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str}, total=False)
+
 AddTagsOutputTypeDef = TypedDict(
     "AddTagsOutputTypeDef",
     {
@@ -104,20 +262,9 @@ CreateMLModelOutputTypeDef = TypedDict(
     "CreateMLModelOutputTypeDef", {"MLModelId": str}, total=False
 )
 
-RealtimeEndpointInfoTypeDef = TypedDict(
-    "RealtimeEndpointInfoTypeDef",
-    {
-        "PeakRequestsPerSecond": int,
-        "CreatedAt": datetime,
-        "EndpointUrl": str,
-        "EndpointStatus": Literal["NONE", "READY", "UPDATING", "FAILED"],
-    },
-    total=False,
-)
-
 CreateRealtimeEndpointOutputTypeDef = TypedDict(
     "CreateRealtimeEndpointOutputTypeDef",
-    {"MLModelId": str, "RealtimeEndpointInfo": RealtimeEndpointInfoTypeDef},
+    {"MLModelId": str, "RealtimeEndpointInfo": "RealtimeEndpointInfoTypeDef"},
     total=False,
 )
 
@@ -139,7 +286,7 @@ DeleteMLModelOutputTypeDef = TypedDict(
 
 DeleteRealtimeEndpointOutputTypeDef = TypedDict(
     "DeleteRealtimeEndpointOutputTypeDef",
-    {"MLModelId": str, "RealtimeEndpointInfo": RealtimeEndpointInfoTypeDef},
+    {"MLModelId": str, "RealtimeEndpointInfo": "RealtimeEndpointInfoTypeDef"},
     total=False,
 )
 
@@ -152,164 +299,36 @@ DeleteTagsOutputTypeDef = TypedDict(
     total=False,
 )
 
-BatchPredictionTypeDef = TypedDict(
-    "BatchPredictionTypeDef",
-    {
-        "BatchPredictionId": str,
-        "MLModelId": str,
-        "BatchPredictionDataSourceId": str,
-        "InputDataLocationS3": str,
-        "CreatedByIamUser": str,
-        "CreatedAt": datetime,
-        "LastUpdatedAt": datetime,
-        "Name": str,
-        "Status": Literal["PENDING", "INPROGRESS", "FAILED", "COMPLETED", "DELETED"],
-        "OutputUri": str,
-        "Message": str,
-        "ComputeTime": int,
-        "FinishedAt": datetime,
-        "StartedAt": datetime,
-        "TotalRecordCount": int,
-        "InvalidRecordCount": int,
-    },
-    total=False,
-)
-
 DescribeBatchPredictionsOutputTypeDef = TypedDict(
     "DescribeBatchPredictionsOutputTypeDef",
-    {"Results": List[BatchPredictionTypeDef], "NextToken": str},
-    total=False,
-)
-
-RDSDatabaseTypeDef = TypedDict(
-    "RDSDatabaseTypeDef", {"InstanceIdentifier": str, "DatabaseName": str}
-)
-
-RDSMetadataTypeDef = TypedDict(
-    "RDSMetadataTypeDef",
-    {
-        "Database": RDSDatabaseTypeDef,
-        "DatabaseUserName": str,
-        "SelectSqlQuery": str,
-        "ResourceRole": str,
-        "ServiceRole": str,
-        "DataPipelineId": str,
-    },
-    total=False,
-)
-
-RedshiftDatabaseTypeDef = TypedDict(
-    "RedshiftDatabaseTypeDef", {"DatabaseName": str, "ClusterIdentifier": str}
-)
-
-RedshiftMetadataTypeDef = TypedDict(
-    "RedshiftMetadataTypeDef",
-    {"RedshiftDatabase": RedshiftDatabaseTypeDef, "DatabaseUserName": str, "SelectSqlQuery": str},
-    total=False,
-)
-
-DataSourceTypeDef = TypedDict(
-    "DataSourceTypeDef",
-    {
-        "DataSourceId": str,
-        "DataLocationS3": str,
-        "DataRearrangement": str,
-        "CreatedByIamUser": str,
-        "CreatedAt": datetime,
-        "LastUpdatedAt": datetime,
-        "DataSizeInBytes": int,
-        "NumberOfFiles": int,
-        "Name": str,
-        "Status": Literal["PENDING", "INPROGRESS", "FAILED", "COMPLETED", "DELETED"],
-        "Message": str,
-        "RedshiftMetadata": RedshiftMetadataTypeDef,
-        "RDSMetadata": RDSMetadataTypeDef,
-        "RoleARN": str,
-        "ComputeStatistics": bool,
-        "ComputeTime": int,
-        "FinishedAt": datetime,
-        "StartedAt": datetime,
-    },
+    {"Results": List["BatchPredictionTypeDef"], "NextToken": str},
     total=False,
 )
 
 DescribeDataSourcesOutputTypeDef = TypedDict(
     "DescribeDataSourcesOutputTypeDef",
-    {"Results": List[DataSourceTypeDef], "NextToken": str},
-    total=False,
-)
-
-PerformanceMetricsTypeDef = TypedDict(
-    "PerformanceMetricsTypeDef", {"Properties": Dict[str, str]}, total=False
-)
-
-EvaluationTypeDef = TypedDict(
-    "EvaluationTypeDef",
-    {
-        "EvaluationId": str,
-        "MLModelId": str,
-        "EvaluationDataSourceId": str,
-        "InputDataLocationS3": str,
-        "CreatedByIamUser": str,
-        "CreatedAt": datetime,
-        "LastUpdatedAt": datetime,
-        "Name": str,
-        "Status": Literal["PENDING", "INPROGRESS", "FAILED", "COMPLETED", "DELETED"],
-        "PerformanceMetrics": PerformanceMetricsTypeDef,
-        "Message": str,
-        "ComputeTime": int,
-        "FinishedAt": datetime,
-        "StartedAt": datetime,
-    },
+    {"Results": List["DataSourceTypeDef"], "NextToken": str},
     total=False,
 )
 
 DescribeEvaluationsOutputTypeDef = TypedDict(
     "DescribeEvaluationsOutputTypeDef",
-    {"Results": List[EvaluationTypeDef], "NextToken": str},
-    total=False,
-)
-
-MLModelTypeDef = TypedDict(
-    "MLModelTypeDef",
-    {
-        "MLModelId": str,
-        "TrainingDataSourceId": str,
-        "CreatedByIamUser": str,
-        "CreatedAt": datetime,
-        "LastUpdatedAt": datetime,
-        "Name": str,
-        "Status": Literal["PENDING", "INPROGRESS", "FAILED", "COMPLETED", "DELETED"],
-        "SizeInBytes": int,
-        "EndpointInfo": RealtimeEndpointInfoTypeDef,
-        "TrainingParameters": Dict[str, str],
-        "InputDataLocationS3": str,
-        "Algorithm": Literal["sgd"],
-        "MLModelType": Literal["REGRESSION", "BINARY", "MULTICLASS"],
-        "ScoreThreshold": float,
-        "ScoreThresholdLastUpdatedAt": datetime,
-        "Message": str,
-        "ComputeTime": int,
-        "FinishedAt": datetime,
-        "StartedAt": datetime,
-    },
+    {"Results": List["EvaluationTypeDef"], "NextToken": str},
     total=False,
 )
 
 DescribeMLModelsOutputTypeDef = TypedDict(
     "DescribeMLModelsOutputTypeDef",
-    {"Results": List[MLModelTypeDef], "NextToken": str},
+    {"Results": List["MLModelTypeDef"], "NextToken": str},
     total=False,
 )
 
-TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str}, total=False)
-
 DescribeTagsOutputTypeDef = TypedDict(
     "DescribeTagsOutputTypeDef",
     {
         "ResourceId": str,
         "ResourceType": Literal["BatchPrediction", "DataSource", "Evaluation", "MLModel"],
-        "Tags": List[TagTypeDef],
+        "Tags": List["TagTypeDef"],
     },
     total=False,
 )
@@ -353,8 +372,8 @@ GetDataSourceOutputTypeDef = TypedDict(
         "Status": Literal["PENDING", "INPROGRESS", "FAILED", "COMPLETED", "DELETED"],
         "LogUri": str,
         "Message": str,
-        "RedshiftMetadata": RedshiftMetadataTypeDef,
-        "RDSMetadata": RDSMetadataTypeDef,
+        "RedshiftMetadata": "RedshiftMetadataTypeDef",
+        "RDSMetadata": "RDSMetadataTypeDef",
         "RoleARN": str,
         "ComputeStatistics": bool,
         "ComputeTime": int,
@@ -377,7 +396,7 @@ GetEvaluationOutputTypeDef = TypedDict(
         "LastUpdatedAt": datetime,
         "Name": str,
         "Status": Literal["PENDING", "INPROGRESS", "FAILED", "COMPLETED", "DELETED"],
-        "PerformanceMetrics": PerformanceMetricsTypeDef,
+        "PerformanceMetrics": "PerformanceMetricsTypeDef",
         "LogUri": str,
         "Message": str,
         "ComputeTime": int,
@@ -398,7 +417,7 @@ GetMLModelOutputTypeDef = TypedDict(
         "Name": str,
         "Status": Literal["PENDING", "INPROGRESS", "FAILED", "COMPLETED", "DELETED"],
         "SizeInBytes": int,
-        "EndpointInfo": RealtimeEndpointInfoTypeDef,
+        "EndpointInfo": "RealtimeEndpointInfoTypeDef",
         "TrainingParameters": Dict[str, str],
         "InputDataLocationS3": str,
         "MLModelType": Literal["REGRESSION", "BINARY", "MULTICLASS"],
@@ -419,31 +438,16 @@ PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
 )
 
-PredictionTypeDef = TypedDict(
-    "PredictionTypeDef",
-    {
-        "predictedLabel": str,
-        "predictedValue": float,
-        "predictedScores": Dict[str, float],
-        "details": Dict[Literal["PredictiveModelType", "Algorithm"], str],
-    },
-    total=False,
-)
-
 PredictOutputTypeDef = TypedDict(
-    "PredictOutputTypeDef", {"Prediction": PredictionTypeDef}, total=False
-)
-
-RDSDatabaseCredentialsTypeDef = TypedDict(
-    "RDSDatabaseCredentialsTypeDef", {"Username": str, "Password": str}
+    "PredictOutputTypeDef", {"Prediction": "PredictionTypeDef"}, total=False
 )
 
 _RequiredRDSDataSpecTypeDef = TypedDict(
     "_RequiredRDSDataSpecTypeDef",
     {
-        "DatabaseInformation": RDSDatabaseTypeDef,
+        "DatabaseInformation": "RDSDatabaseTypeDef",
         "SelectSqlQuery": str,
-        "DatabaseCredentials": RDSDatabaseCredentialsTypeDef,
+        "DatabaseCredentials": "RDSDatabaseCredentialsTypeDef",
         "S3StagingLocation": str,
         "ResourceRole": str,
         "ServiceRole": str,
@@ -462,16 +466,12 @@ class RDSDataSpecTypeDef(_RequiredRDSDataSpecTypeDef, _OptionalRDSDataSpecTypeDe
     pass
 
 
-RedshiftDatabaseCredentialsTypeDef = TypedDict(
-    "RedshiftDatabaseCredentialsTypeDef", {"Username": str, "Password": str}
-)
-
 _RequiredRedshiftDataSpecTypeDef = TypedDict(
     "_RequiredRedshiftDataSpecTypeDef",
     {
-        "DatabaseInformation": RedshiftDatabaseTypeDef,
+        "DatabaseInformation": "RedshiftDatabaseTypeDef",
         "SelectSqlQuery": str,
-        "DatabaseCredentials": RedshiftDatabaseCredentialsTypeDef,
+        "DatabaseCredentials": "RedshiftDatabaseCredentialsTypeDef",
         "S3StagingLocation": str,
     },
 )
